@@ -17,6 +17,9 @@
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# 权限组被绑定。
+FAILEDOPERATION_ACCESSGROUPBOUND = 'FailedOperation.AccessGroupBound'
+
 # 文件系统非空。
 FAILEDOPERATION_FILESYSTEMNOTEMPTY = 'FailedOperation.FileSystemNotEmpty'
 
@@ -68,9 +71,6 @@ LIMITEXCEEDED = 'LimitExceeded'
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
-# 操作被拒绝。
-OPERATIONDENIED = 'OperationDenied'
-
 # 资源被占用。
 RESOURCEINUSE = 'ResourceInUse'
 
